
// used in src/Languages.cpp
const wxString langNames[] =
{
  wxString("Catal", wxConvISO8859_1),
  wxT("Česky"),
  wxT("Dansk"),
  wxT("Deutsch"),
  wxT("English"),
  wxString("Espaol", wxConvISO8859_1),
  wxT("Euskara"),
  wxString("Franais", wxConvISO8859_1),
  wxT("Italiano"),
  wxString("日本語 [jp]", wxConvUTF8),
  wxT("Magyar"),
  wxT("Nederlands"),
  wxT("Polski"),
  wxString("Portugus", wxConvISO8859_1),
  wxString("Portugus (Brasil)", wxConvISO8859_1),
  wxString(" [ru]", *(new wxCSConv(_T("KOI8-R")))),
  wxString("Slovenčina", wxConvUTF8),
  wxT("Srpski"),
  wxT("Svenska")
};

const wxLanguage langIds[] =
{
  wxLANGUAGE_CATALAN,
  wxLANGUAGE_CZECH,
  wxLANGUAGE_DANISH,
  wxLANGUAGE_GERMAN,
  wxLANGUAGE_ENGLISH,
  wxLANGUAGE_SPANISH,
  wxLANGUAGE_BASQUE,
  wxLANGUAGE_FRENCH,
  wxLANGUAGE_ITALIAN,
  wxLANGUAGE_JAPANESE,
  wxLANGUAGE_HUNGARIAN,
  wxLANGUAGE_DUTCH,
  wxLANGUAGE_POLISH,
  wxLANGUAGE_PORTUGUESE,
  wxLANGUAGE_PORTUGUESE_BRAZILIAN,
  wxLANGUAGE_RUSSIAN,
  wxLANGUAGE_SLOVAK,
  wxLANGUAGE_SERBIAN,
  wxLANGUAGE_SWEDISH
};
